==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/default/xtheaderHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTablΥإåѹ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-a*/
#define FNMT "̾ꥹ"
#define FNMC "ǻꤷ̾ꥹȤѹ"

/*-l*/
#define TITT "ȥ"
#define TITC "ǻꤷȥѹ"

/*-c*/
#define COMT ""
#define COMC "ǻꤷȤѹ"

/*-I*/
#define IMPT "ݡȥե̾"
#define IMPC "إå򥤥ݡȤΥإåѹ"

/*-S*/
#define SRTT "Ⱦõ"
#define SRTC "إåιܾΤȾΤߤõ롣"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "إå(̾,ȥ,)ѹ롣"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtheader -a ܵ,ǯ, -i dat.xt -o rsl.xt\n\
xtheader -l ܵҥޥ -c 2002ǯ0101 -i dat.xt -o rsl.xt\n\
xtheader -S -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtmkheader,xtmkdata"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre4.tar.gz: musashi-core-1.0.4-pre4/help/default/xtheaderHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTablΥإåѹ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-a*/
#define FNMT "̾ꥹ"
#define FNMC "ǻꤷ̾ꥹȤѹ"

/*-f*/
#define FLDT "ʬŪѹ̾ꥹ"
#define FLDC "ʬŪʹ̾ѹֵ̾:̾פηǻꤹ"
#define FLDF NULL

/*-l*/
#define TITT "ȥ"
#define TITC "ǻꤷȥѹ"

/*-c*/
#define COMT ""
#define COMC "ǻꤷȤѹ"

/*-I*/
#define IMPT "ݡȥե̾"
#define IMPC "إå򥤥ݡȤΥإåѹ"

/*-S*/
#define SRTT "Ⱦõ"
#define SRTC "إåιܾΤȾΤߤõ롣"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "إå(̾,ȥ,)ѹ롣"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtheader -a ܵ,ǯ, -i dat.xt -o rsl.xt\n\
xtheader -l ܵҥޥ -c 2002ǯ0101 -i dat.xt -o rsl.xt\n\
xtheader -S -i dat.xt -o rsl.xt\n\
xtheader -f ǯ:,:gender -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtmkheader,xtmkdata"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
